from bi_sc_client.client import BISomConnexioClient
from bi_sc_client.resources.token import Token


class NotifyInvoiceNumber:
    def __init__(self, invoice_number):
        self.invoice_number = invoice_number
        self.path = "/apidata/invoices_oc_pdf/"
        self.client = BISomConnexioClient()
        self.headers = {"Authorization": Token(self.client).token}
        self.params = {"invoice": self.invoice_number}

    def run(self):
        self.client.send_request("GET", self.path, self.params, self.headers)



import os
import urllib

import requests

from bi_sc_client.errors import ErrorApiResponse


class BISomConnexioClient:
    def __init__(self):
        self.url = os.getenv("BI_URL")

    def send_request(self, method, path, content, headers={}):
        headers.update({"accept": "application/json"})

        url = urllib.parse.urljoin(self.url, path)

        if method == "GET":
            response = requests.get(
                url=url,
                params=content,
                headers=headers,
            )
        elif method == "POST":
            response = requests.post(
                url=url,
                data=content,
                headers=headers,
            )

        if not response.ok or response.status_code != 200:
            raise ErrorApiResponse(response.text)
        return response



import os

import mock
import unittest2 as unittest
from bi_sc_client.client import BISomConnexioClient
from bi_sc_client.resources.token import Token

USER = "fakeuser"
PASSWORD = "fakepassword"
URL = "https://fake.url/"


@mock.patch.dict(
    os.environ,
    {
        "BI_USER": USER,
        "BI_PASSWORD": PASSWORD,
        "BI_URL": URL,
    },
    clear=True,
)
class TokenTestCase(unittest.TestCase):
    def test_create_token_ok(self):
        token_str = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJhcGlvZG9vIiwiZXhwIjoxNzAyODkwOTQyfQ.iwPnXGmQd9Fkxcb-fg_kKYUxjfUHZsSv8gqV2-KwERQ"  # noqa

        BISomConnexioClientMock = mock.create_autospec(BISomConnexioClient)
        client = BISomConnexioClientMock()

        client.send_request.return_value = mock.Mock(spec=["json"])
        client.send_request.return_value.json.return_value = {
            "access_token": token_str,
            "token_type": "bearer",
        }

        token = Token(client)

        assert token.token == f"bearer {token_str}"
        client.send_request.assert_called_once_with(
            "POST",
            token.path,
            {
                "grant_type": None,
                "username": USER,
                "password": PASSWORD,
                "scope": None,
                "client_id": None,
                "client_secret": None,
            },
            {"Content-Type": "application/x-www-form-urlencoded"},
        )



# -*- coding: utf-8 -*-
from setuptools import find_packages, setup

with open("README.md") as f:
    README = f.read()


VERSION = "0.0.3"


setup(
    name="bi-sc-client",
    version=VERSION,
    author="Coopdevs, Som Connexio",
    author_email="info@coopdevs.org",
    maintainer="Daniel Palomar",
    url="https://git.coopdevs.org/coopdevs/som-connexio/bi/bi-sc-client",
    description="Python wrapper for BI SomConnexió API",
    long_description=README,
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=("tests", "docs")),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "requests == 2.28.1",
    ],
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 3 - Alpha",
        "Operating System :: POSIX :: Linux",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
)



import os


class Token:
    def __init__(self, client):
        self.user = os.getenv("BI_USER")
        self.password = os.getenv("BI_PASSWORD")
        self.grant_type = os.getenv("BI_GRANT_TYPE")
        self.scope = os.getenv("BI_SCOPE")
        self.client_id = os.getenv("BI_CLIENT_ID")
        self.client_secret = os.getenv("BI_CLIENT_SECRET")
        self.client = client
        self.path = "/apidata/token"
        self._create()

    @property
    def token(self):
        return f"{self.token_type} {self.access_token}"

    def _create(self):
        headers = {"Content-Type": "application/x-www-form-urlencoded"}
        params = {
            "grant_type": self.grant_type,
            "username": self.user,
            "password": self.password,
            "scope": self.scope,
            "client_id": self.client_id,
            "client_secret": self.client_secret,
        }
        response = self.client.send_request("POST", self.path, params, headers)
        response = response.json()
        self.token_type = response.get("token_type")
        self.access_token = response.get("access_token")
